==> peg-solitaire_1.1.2.orig.tar.gz: peg-solitaire-1.1.2/scr/funcions.cpp <==
/***********************************************************************
 *
 * Copyright (C) 2010-2011 Innocent De Marchi <tangram.peces@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ***********************************************************************/
#include "funcions.h"

#include "constants.h"



/*
  Directoris linux
 */
QString directoriLinux(){
 QString dirInicial=QCoreApplication::applicationDirPath().replace(DIRECTORIS_LINUX_PROGRAMA,"");
 dirInicial=dirInicial.append(DIRECTORIS_LINUX_AUXILIARS);
 QDir dirArxiu;
    if (dirArxiu.exists(DIRECTORIS_LINUX)){
       return DIRECTORIS_LINUX;
    }
    else if (dirArxiu.exists(dirInicial)){
        return dirInicial;
    }
    else return QCoreApplication::applicationDirPath();
}



/*
  Número de fitxes de la configuració passada per parámetre
  */
int numeroConfiguracio(QString config){
  int numero=0;
     for(int llista=0 ; llista<config.size();++llista){
         numero=numero+config.mid(llista,1).toInt();
     }
   //  qDebug("numero configuracio %d",numero);
     return numero;
}

==> peg-solitaire_1.2.orig.tar.gz: peg-solitaire-1.2/scr/funcions.cpp <==
/***********************************************************************
 *
 * Copyright (C) 2010-2011 Innocent De Marchi <tangram.peces@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 ***********************************************************************/
#include "funcions.h"

#include "constants.h"



/*
  Directoris linux
  21/04/11
  Modificat per permetre la coexistència de l'aplicació instal·lada
  i el codi font
 */
QString directoriLinux(){  
    QDir dirArxiu;
     if (dirArxiu.exists(QCoreApplication::applicationDirPath()+ QDir().separator()+
                         "images")){
         return QCoreApplication::applicationDirPath();
     }
     else if (dirArxiu.exists(DIRECTORIS_LINUX)){
         return DIRECTORIS_LINUX;
      }
     else return QCoreApplication::applicationDirPath();
 /*
 QString dirInicial=QCoreApplication::applicationDirPath().replace(DIRECTORIS_LINUX_PROGRAMA,"");
 dirInicial=dirInicial.append(DIRECTORIS_LINUX_AUXILIARS);
 QDir dirArxiu;
    if (dirArxiu.exists(DIRECTORIS_LINUX)){
       return DIRECTORIS_LINUX;
    }
    else if (dirArxiu.exists(dirInicial)){
        return dirInicial;
    }
    else return QCoreApplication::applicationDirPath();
    */
}



/*
  Número de fitxes de la configuració passada per parámetre
  */
int numeroConfiguracio(QString config){
  int numero=0;
     for(int llista=0 ; llista<config.size();++llista){
         numero=numero+config.mid(llista,1).toInt();
     }
   //  qDebug("numero configuracio %d",numero);
     return numero;
}
